==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/GetRateBasedRuleResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetRateBasedRuleResponse(
    rule: Option[zio.aws.waf.model.RateBasedRule] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse = {
    import GetRateBasedRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse
      .builder()
      .optionallyWith(rule.map(value => value.buildAwsValue()))(_.rule)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetRateBasedRuleResponse.ReadOnly =
    zio.aws.waf.model.GetRateBasedRuleResponse.wrap(buildAwsValue())
}
object GetRateBasedRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetRateBasedRuleResponse =
      zio.aws.waf.model
        .GetRateBasedRuleResponse(rule.map(value => value.asEditable))
    def rule: Option[zio.aws.waf.model.RateBasedRule.ReadOnly]
    def getRule: ZIO[Any, AwsError, zio.aws.waf.model.RateBasedRule.ReadOnly] =
      AwsError.unwrapOptionField("rule", rule)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse
  ) extends zio.aws.waf.model.GetRateBasedRuleResponse.ReadOnly {
    override val rule: Option[zio.aws.waf.model.RateBasedRule.ReadOnly] = scala
      .Option(impl.rule())
      .map(value => zio.aws.waf.model.RateBasedRule.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse
  ): zio.aws.waf.model.GetRateBasedRuleResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-waf_2.13-5.19.8.4-sources.jar: zio/aws/waf/model/GetRateBasedRuleResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetRateBasedRuleResponse(
    rule: Optional[zio.aws.waf.model.RateBasedRule] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse = {
    import GetRateBasedRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse
      .builder()
      .optionallyWith(rule.map(value => value.buildAwsValue()))(_.rule)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetRateBasedRuleResponse.ReadOnly =
    zio.aws.waf.model.GetRateBasedRuleResponse.wrap(buildAwsValue())
}
object GetRateBasedRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetRateBasedRuleResponse =
      zio.aws.waf.model
        .GetRateBasedRuleResponse(rule.map(value => value.asEditable))
    def rule: Optional[zio.aws.waf.model.RateBasedRule.ReadOnly]
    def getRule: ZIO[Any, AwsError, zio.aws.waf.model.RateBasedRule.ReadOnly] =
      AwsError.unwrapOptionField("rule", rule)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse
  ) extends zio.aws.waf.model.GetRateBasedRuleResponse.ReadOnly {
    override val rule: Optional[zio.aws.waf.model.RateBasedRule.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.rule())
        .map(value => zio.aws.waf.model.RateBasedRule.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetRateBasedRuleResponse
  ): zio.aws.waf.model.GetRateBasedRuleResponse.ReadOnly = new Wrapper(impl)
}
